Appellate Division, Second Department, Decisions

2003

2003

2003

2004

2004

2004

2005

2005

2005

2006

2006

2006

2007

2007

2007

2008

2008

2008

2009

2009

2009

2010

2010

2010

2011

2011

2011

2012

2012

2012

2013

2013

2013

2014

2014

2014

Home > Decisions
Home Decisions Advanced Search Style Manual Research Citation Services

Archives

May, 2014
Cases Decided May 28, 2014
Title | Judge | Docket No. | Slip Opinion No.
Abreu v Metropolitan Transp. Auth. |  | 2012-09567 | 2014 NY Slip Op 03787
American Airlines Fed. Credit Union v Mohamed |  | 2013-00081 | 2014 NY Slip Op 03788
Apladenaki v Greenpoint Mtge. Funding, Inc. |  | 2010-09028 | 2014 NY Slip Op 03789
Apladenaki v Greenpoint Mtge. Funding, Inc. |  | 2012-03177 | 2014 NY Slip Op 03790
Kolb v LJ Rabinowitz, CPA |  | 2013-04128 | 2014 NY Slip Op 03791
Collazo v State of New York |  | 2012-10154 | 2014 NY Slip Op 03792
Daniels v City of New York |  | 2012-03250 | 2014 NY Slip Op 03793
Deutsche Bank Natl. Trust Co. v Joseph |  | 2012-03293 | 2014 NY Slip Op 03794
DiMaggio v Cataletto |  | 2012-10757 | 2014 NY Slip Op 03795
Gomez v Our Lady of Fatima Church |  | 2012-11243 | 2014 NY Slip Op 03796
Iacono v Iacono |  | 2013-09503 | 2014 NY Slip Op 03797
Jean v Joseph |  | 2012-03435 | 2014 NY Slip Op 03798
KeyBank Natl. Assn. v Chapman Steamer Collective, LLC |  | 2013-00171 | 2014 NY Slip Op 03799
Lane Constr. Co., Inc. v Chayat |  | 2013-02305 | 2014 NY Slip Op 03800
Lehneis v Neill |  | 2012-11002 | 2014 NY Slip Op 03801
Mannino Dev., Inc. v Linares |  | 2012-02688 | 2014 NY Slip Op 03802
Margolin v Margolin |  | 2012-02327 | 2014 NY Slip Op 03803
McNeil v HMB E. 40th St. Corp. |  | 2013-02916 | 2014 NY Slip Op 03804
Mobarak v Mowad |  | 2012-11350 | 2014 NY Slip Op 03805
Mondshein v Mondshein |  | 2012-10083 | 2014 NY Slip Op 03806
Montalvo v United Parcel Serv., Inc. |  | 2013-06248 | 2014 NY Slip Op 03807
Nagan Constr., Inc. v Monsignor McClancy Mem. High School |  | 2012-10292 | 2014 NY Slip Op 03808
Neve v City of New York |  | 2012-06639 | 2014 NY Slip Op 03809
Neves v Katonah-Lewisboro School Dist. |  | 2013-00105 | 2014 NY Slip Op 03810
New Century Mtge. Corp. v Corriette |  | 2013-03535 | 2014 NY Slip Op 03811
New York Univ. Hospital-Tisch Inst. v Government Employees Ins. Co. |  | 2011-10380 | 2014 NY Slip Op 03812
O'Rourke v Carucci |  | 2012-06133 | 2014 NY Slip Op 03813
Ortiz v 82-90 Broadway Realty Corp. |  | 2013-00606 | 2014 NY Slip Op 03814
People v DeJesus |  | 2012-02486 | 2014 NY Slip Op 03815
People v Patronick |  | 2013-00196 | 2014 NY Slip Op 03816
People v Rotunno |  | 2013-07358 | 2014 NY Slip Op 03817
Ragins v Hospitals Ins. Co., Inc. |  | 2011-06924 | 2014 NY Slip Op 03818
Rodrigues v Samaras |  | 2014-00146 | 2014 NY Slip Op 03819
Sanabria v Borges |  | 2012-10923 | 2014 NY Slip Op 03820
Santoro v Geico |  | 2012-10740 | 2014 NY Slip Op 03821
Texas 1845, LLC v Kyaw |  | 2012-08699 | 2014 NY Slip Op 03822
Texas 1845, LLC v Kyaw |  | 2013-03296 | 2014 NY Slip Op 03823
Trader v New York City Hous. Auth. |  | 2013-01984 | 2014 NY Slip Op 03824
Vaccaro v Weinstein |  | 2012-05610 | 2014 NY Slip Op 03825
Waldorf v Waldorf |  | 2012-09772 | 2014 NY Slip Op 03826
Weinstein v Nicolosi |  | 2012-11104 | 2014 NY Slip Op 03827
Yassa v Awad |  | 2013-00526 | 2014 NY Slip Op 03828
Zelichenko v 301 Oriental Blvd., LLC |  | 2013-06817 | 2014 NY Slip Op 03829
Zellner v Odyl, LLC |  | 2013-02613 | 2014 NY Slip Op 03830
Matter of Eddie Z. B. (Henrietta W.) |  | 2012-04798 | 2014 NY Slip Op 03831
Matter of Naydia A. B. (Jessica C.) |  | 2012-08882 | 2014 NY Slip Op 03832
Matter of Jessica C. (Johanna B.) |  | 2013-04506 | 2014 NY Slip Op 03833
Matter of Capece v Schultz |  | 2012-03257 | 2014 NY Slip Op 03834
Matter of Brandon F. |  | 2013-07290 | 2014 NY Slip Op 03835
Matter of Feldman v Torres |  | 2013-06950 | 2014 NY Slip Op 03836
Matter of Travis G. (Carmen M.) |  | 2013-02324 | 2014 NY Slip Op 03837
Matter of Gutman v Schmidt |  | 2014-03042 | 2014 NY Slip Op 03838
Matter of Zebadiah Z.W.A. H. |  | 2013-02892 | 2014 NY Slip Op 03839
Matter of Latisha T'Keyah J. (Monie J.) |  | 2012-10933 | 2014 NY Slip Op 03840
Matter of Katz v Katz |  | 2013-01750 | 2014 NY Slip Op 03841
Matter of Shamik M. |  | 2013-04821 | 2014 NY Slip Op 03842
Matter of McAvoy v Klein |  | 2012-04744, | 2014 NY Slip Op 03843
Matter of McCarthy v Brittingham-Bank |  | 2013-04196 | 2014 NY Slip Op 03844
Matter of New v Sharma |  | 2013-01524 | 2014 NY Slip Op 03845
Matter of Rosenblum v Tallman Fire Dist. |  | 2014-01454 | 2014 NY Slip Op 03846
Matter of Shydasha J. S. (Smith) |  | 2013-03106 | 2014 NY Slip Op 03847
Matter of Sledjeski | Per Curiam. | 2013-06689 | 2014 NY Slip Op 03848
Matter of Sorenson v Cassano |  | 2012-10915 | 2014 NY Slip Op 03849
Matter of Zarvela v Banks |  | 2012-10020 | 2014 NY Slip Op 03850
People v Avila |  | 2012-10862 | 2014 NY Slip Op 03851
People v Benloss |  | 2013-00239 | 2014 NY Slip Op 03852
People v Casarrubia |  | 2012-06241 | 2014 NY Slip Op 03853
People v Charles |  | 2010-09551 | 2014 NY Slip Op 03854
People v Currie |  | 2006-09104 | 2014 NY Slip Op 03855
People v DiPippo |  | 2012-08267 | 2014 NY Slip Op 03856
People v Frazier |  | 2010-03300 | 2014 NY Slip Op 03857
People v Fulcher |  | 2007-11070 | 2014 NY Slip Op 03858
People v Gary |  | 2010-07398 | 2014 NY Slip Op 03859
People v Hicks |  | 2013-08273 | 2014 NY Slip Op 03860
People v Jacob |  | 2011-11083 | 2014 NY Slip Op 03861
People v Katehis |  | 2011-11958 | 2014 NY Slip Op 03862
People v Mazariego |  | 2012-07025 | 2014 NY Slip Op 03863
People v Mazyck |  | 2013-03136 | 2014 NY Slip Op 03864
People v Munford |  | 2004-09770 | 2014 NY Slip Op 03865
People v Oliphant |  | 2011-02793 | 2014 NY Slip Op 03866
People v Pierre |  | 2007-00899 | 2014 NY Slip Op 03867
People v Popal |  | 2011-02093 | 2014 NY Slip Op 03868
People v Rasheed |  | 2012-06691 | 2014 NY Slip Op 03869
People v Sabo |  | 2012-05544 | 2014 NY Slip Op 03870
People v Statini |  | 2013-05058 | 2014 NY Slip Op 03871
People v Tucker |  | 2010-04587 | 2014 NY Slip Op 03872
People v Washington |  | 2010-11824 | 2014 NY Slip Op 03873
People v Watkins |  | 2011-10772 | 2014 NY Slip Op 03874
Cases Decided May 21, 2014
Title | Judge | Docket No. | Slip Opinion No.
Arcamone-Makinano v Britton Prop., Inc. |  | 2012-10376 | 2014 NY Slip Op 03644
Clark v Amboy Bus Co. |  | 2013-00073 | 2014 NY Slip Op 03645
Delvalle v Mercedes Benz USA, LLC |  | 2012-08038 | 2014 NY Slip Op 03646
Delvalle v Mercedes Benz USA, LLC |  | 2013-04450 | 2014 NY Slip Op 03647
Fink v DeAngelis |  | 2012-10618 | 2014 NY Slip Op 03648
Firdous Oriental Rugs, Inc. v M & G Brokerage, Inc. |  | 2012-11416 | 2014 NY Slip Op 03649
Francis v Super Clean Laundromat, Inc. |  | 2012-01276 | 2014 NY Slip Op 03650
Frederic v City of New York |  | 2012-04956 | 2014 NY Slip Op 03651
Godoy v Central Islip Union Free Sch. Dist. |  | 2012-09823 | 2014 NY Slip Op 03652
Gooden v Gooden |  | 2012-05156 | 2014 NY Slip Op 03653
Hasson v S.B.J. Assoc., LLC |  | 2012-10417 | 2014 NY Slip Op 03654
Island Tennis, LP v Varilease Fin., Inc. |  | 2013-04148 | 2014 NY Slip Op 03655
Javid v Sclafmore Constr. |  | 2013-01620 | 2014 NY Slip Op 03656
Jessabell Realty Corp. v Gonzales |  | 2012-05066 | 2014 NY Slip Op 03657
JP Morgan Chase Bank, N.A. v Smith Elec. Contr., Inc. |  | 2013-01020 | 2014 NY Slip Op 03658
Karimov v Brown Harris Stevens Residential Mgt., LLC |  | 2013-06197 | 2014 NY Slip Op 03659
Kelly v Karsenty |  | 2013-00178 | 2014 NY Slip Op 03660
Lin v City of New York |  | 2012-05981 | 2014 NY Slip Op 03661
Lizjan, Inc. v Sahn Ward Coschignano & Baker, PLLC |  | 2012-09606 | 2014 NY Slip Op 03662
Maloney v Farris |  | 2012-08355 | 2014 NY Slip Op 03663
Marcum, LLP v Silva |  | 2012-11165 | 2014 NY Slip Op 03664
Marcum, LLP v Silva |  | 2013-04984 | 2014 NY Slip Op 03665
Meyer v Staten Is. Univ. Hosp. |  | 2012-10394 | 2014 NY Slip Op 03666
Mount Sinai Hosp. v Dust Tr., Inc. |  | 2011-10406 | 2014 NY Slip Op 03667
Neckles Bldrs., Inc. v Turner |  | 2013-03272 | 2014 NY Slip Op 03668
Ozkurt v Hyatt Realty, LLC |  | 2012-10384 | 2014 NY Slip Op 03669
People v Rosen |  | 2013-08115 | 2014 NY Slip Op 03670
Persaud v Palmer |  | 2012-08665 | 2014 NY Slip Op 03671
Qurashi v Reliastar Life Ins. Co. of N.Y. |  | 2012-08435 | 2014 NY Slip Op 03672
Ramirez v Genovese |  | 2012-07128 | 2014 NY Slip Op 03673
Ramirez v McAllister |  | 2013-07510 | 2014 NY Slip Op 03674
Rogers v Bloomingdale's, Inc. |  | 2012-11378 | 2014 NY Slip Op 03675
Scalogna v Osipov |  | 2012-08748 | 2014 NY Slip Op 03676
Schofield v Edward B. Borden, M.D., P.C. |  | 2012-09964 | 2014 NY Slip Op 03677
Twaddell v Drop & Lock Stor. Co., Inc. |  | 2013-08810 | 2014 NY Slip Op 03678
Vaughn v Veolia Transp., Inc. |  | 2013-05736 | 2014 NY Slip Op 03679
Zanani v Schvimmer |  | 2012-10924 | 2014 NY Slip Op 03680
Zhiwei Mao v Krantz & Levinson Realty Corp. |  | 2013-07505 | 2014 NY Slip Op 03681
Matter of Brown v People of State of N.Y. |  | 2014-02186, | 2014 NY Slip Op 03682
Matter of Country-Wide Ins. Co. v Sharon Bloomfield-Palmer |  | 2013-05664 | 2014 NY Slip Op 03683
Matter of Hon v Tin Yat Chin |  | 2013-02126 | 2014 NY Slip Op 03684
Matter of Huntley v Bartlett |  | 2014-01837 | 2014 NY Slip Op 03685
Matter of Kennedy v New York State Bd. of Parole |  | 2013-03170 | 2014 NY Slip Op 03686
Matter of Mazur Bros. Realty, LLC v State of New York |  | 2013-00908 | 2014 NY Slip Op 03687
Matter of McEvoy v Oyster Bay Fire Co. No. 1 |  | 2012-05377 | 2014 NY Slip Op 03688
Matter of New York City Tr. Auth. v Transport Workers Union of Greater N.Y., Local 100 |  | 2012-05377 | 2014 NY Slip Op 03689
Matter of Marvin P | Chambers | 2012-08392 | 2014 NY Slip Op 03690
Matter of Evelyn R. (Franklin R.) |  | 2013-00771 | 2014 NY Slip Op 03691
Matter of Rodriguez v Justices of the Supreme Ct. of the State of N.Y., Queens County |  | 2014-02654 | 2014 NY Slip Op 03692
Matter of Symes v New York State Bd. of Parole |  | 2013-06917 | 2014 NY Slip Op 03693
Matter of Jayson V. |  | 2013-07131 | 2014 NY Slip Op 03694
Matter of Yuan v Sawyer |  | 2013-08300 | 2014 NY Slip Op 03695
People v Brown |  | 2011-07092 | 2014 NY Slip Op 03696
People v Chery |  | 2012-05043 | 2014 NY Slip Op 03697
People v Hiraeta |  | 2010-04564 | 2014 NY Slip Op 03698
People v Jackson |  | 2011-11076 | 2014 NY Slip Op 03699
People v Jarvis |  | 2012-02975 | 2014 NY Slip Op 03700
People v McFarlane |  | 2010-07943 | 2014 NY Slip Op 03701
People v Mitchell |  | 2012-08450 | 2014 NY Slip Op 03702
People v Mitchell |  | 2011-11815 | 2014 NY Slip Op 03703
People v Thomas |  | 2012-08352 | 2014 NY Slip Op 03704
Cases Decided May 14, 2014
Title | Judge | Docket No. | Slip Opinion No.
Airtight Sec. Sys., Inc. v 2350, LLC |  | 2012-11006 | 2014 NY Slip Op 03466
Alvarez v Wright |  | 2013-03267 | 2014 NY Slip Op 03467
Basile v Wiggs |  | 2012-11417 | 2014 NY Slip Op 03468
Breidbart v Wiesenthal |  | 2012-09186 | 2014 NY Slip Op 03469
Carrion v 162 Pulaski, LLC |  | 2012-03579 | 2014 NY Slip Op 03470
Cotto v Scott |  | 2014-00232 | 2014 NY Slip Op 03471
County of Suffolk v Long Is. Power Auth. |  | 2012-06665 | 2014 NY Slip Op 03472
Couvertier v Concourse Rehabilitation & Nursing, Inc. |  | 2012-09459 | 2014 NY Slip Op 03473
DeLaurentis v Orange Regional Med. Center-Horton Campus |  | 2012-09459 | 2014 NY Slip Op 03474
Deutsch v Woodridge Segway, LLC |  | 2013-01220 | 2014 NY Slip Op 03475
Diaz v City of New York |  | 2013-03253 | 2014 NY Slip Op 03476
Eisner v M & E Rubin, LLC |  | 2012-09214 | 2014 NY Slip Op 03477
Fairchild Corp. v State of New York |  | 2012-09758 | 2014 NY Slip Op 03478
Felix v Duane |  | 2013-08758 | 2014 NY Slip Op 03479
Friedman v 1753 Realty Co. |  | 2012-10107 | 2014 NY Slip Op 03480
Fudge v North Shore- Long Is. Jewish Health Servs. Plainview |  | 2013-06042 | 2014 NY Slip Op 03481
Garris v Lindemann |  | 2012-09995 | 2014 NY Slip Op 03482
Gibson v Singh Towing, Inc. |  | 2013-00339 | 2014 NY Slip Op 03483
Grundstrom v Papadopoulos |  | 2012-09415 | 2014 NY Slip Op 03484
Gwinn v Christina's Polish Rest., Inc. |  | 2013-07889 | 2014 NY Slip Op 03485
Harris v City of New York |  | 2013-06661 | 2014 NY Slip Op 03486
Harris v Thompson |  | 2012-09839 | 2014 NY Slip Op 03487
Hayes v Barroga-Hayes |  | 2012-06998 | 2014 NY Slip Op 03488
Henry v Higgins |  | 2013-01423 | 2014 NY Slip Op 03489
Hidalgo v 4-34-68, Inc. |  | 2012-03965 | 2014 NY Slip Op 03490
Hidalgo v 4-34-68, Inc. |  | 2013-03511 | 2014 NY Slip Op 03491
Himmelburger v Buchris |  | 2013-01186 | 2014 NY Slip Op 03492
Hoque v Achiron |  | 2013-05845 | 2014 NY Slip Op 03493
Kenda v Dunn |  | 2012-07619 | 2014 NY Slip Op 03494
Mamani v Kiesling |  | 2013-05445 | 2014 NY Slip Op 03495
Marshall v Marshall |  | 2013-08734 | 2014 NY Slip Op 03496
McCoy v McCoy |  | 2011-05296 | 2014 NY Slip Op 03497
McKay v Groesbeck |  | 2012-06319 | 2014 NY Slip Op 03498
Miyahara v Majsak |  | 2011-10702 | 2014 NY Slip Op 03499
People v Pizzo |  | 2011-03837 | 2014 NY Slip Op 03500
Romano v Persky |  | 2012-07722 | 2014 NY Slip Op 03501
Shea v Massapequa Union Free Sch. Dist. |  | 2013-07062 | 2014 NY Slip Op 03502
Singh v Singh |  | 2013-06270 | 2014 NY Slip Op 03503
Sirlin v Schreib |  | 2013-07020 | 2014 NY Slip Op 03504
Stephen v State of New York |  | 2012-02939 | 2014 NY Slip Op 03505
Stephen v State of New York |  | 2013-04000 | 2014 NY Slip Op 03506
Wisselman, Harounian & Assoc., P.C. v Dowlah |  | 2013-08448 | 2014 NY Slip Op 03507
Wysocka v Neglia |  | 2013-04775 | 2014 NY Slip Op 03508
Matter of Anderson | Per Curiam. | 2012-07002 | 2014 NY Slip Op 03509
Matter of Azor v DiMango |  | 2014-01765, | 2014 NY Slip Op 03510
Matter of Blair | Per Curiam. | 2012-04175 | 2014 NY Slip Op 03511
Matter of Bonilla v Acosta |  | 2013-01740 | 2014 NY Slip Op 03512
Matter of Leichter-Kessler v Kessler |  | 2013-02572 | 2014 NY Slip Op 03513
Matter of Judge M. (Matthew M.) |  | 2013-01768 | 2014 NY Slip Op 03514
Matter of Madden v Ruskiewicz |  | 2013-05324 | 2014 NY Slip Op 03515
Matter of Marino v Hubert |  | 2013-04497 | 2014 NY Slip Op 03516
Matter of Odery | Per Curiam. | 2013-07327 | 2014 NY Slip Op 03517
Matter of Parietti v Sampson |  | 2013-04537 | 2014 NY Slip Op 03518
Matter of Parietti v Sampson |  | 2013-04544 | 2014 NY Slip Op 03519
Matter of Parietti v Sampson |  | 2013-07242 | 2014 NY Slip Op 03520
Matter of Richards v Board of Fire Commr. of Brentwood Fire Dist. |  | 2012-06745 | 2014 NY Slip Op 03521
Matter of Soto | Per Curiam. | 2011-10442 | 2014 NY Slip Op 03522
Matter of Streat v Streat |  | 2013-05389 | 2014 NY Slip Op 03523
Matter of Toscano | Per Curiam. | 2010-05894 | 2014 NY Slip Op 03524
Matter of Walker |  | 2012-08397 | 2014 NY Slip Op 03525
People v Baldwin |  | 2012-02559 | 2014 NY Slip Op 03526
People v Caraway |  | 2012-05962 | 2014 NY Slip Op 03527
People v Davis |  | 2012-05222 | 2014 NY Slip Op 03528
People v Durham |  | 2011-02310 | 2014 NY Slip Op 03529
People v Ellis |  | 2009-02434 | 2014 NY Slip Op 03530
People v Gore |  | 2010-07655 | 2014 NY Slip Op 03531
People v Harris |  | 2005-02998 | 2014 NY Slip Op 03532
People v Harvey |  | 2011-07890 | 2014 NY Slip Op 03533
People v Jean |  | 2011-04156 | 2014 NY Slip Op 03534
People v Jones |  | 2012-07771 | 2014 NY Slip Op 03535
People v LaPierre |  | 2008-02548 | 2014 NY Slip Op 03536
People v Maffei |  | 2010-10184 | 2014 NY Slip Op 03537
People v Moreno |  | 2012-10160 | 2014 NY Slip Op 03538
People v Mamadou N. |  | 2012-10160 | 2014 NY Slip Op 03539
People v Newsom |  | 2011-04914 ON MOTION | 2014 NY Slip Op 03540
People v Nichols |  | 2013-00398 | 2014 NY Slip Op 03541
People v Porco |  | 2007-04459 | 2014 NY Slip Op 03542
People v Ray |  | 2010-09278 | 2014 NY Slip Op 03543
People v Rosado |  | 2013-03395 | 2014 NY Slip Op 03544
People v Swails |  | 2011-02796 | 2014 NY Slip Op 03545
People v Vargas |  | 2012-05626 | 2014 NY Slip Op 03546
People v Walker |  | 2011-11042 | 2014 NY Slip Op 03547
People v White |  | 2013-02318 | 2014 NY Slip Op 03548
People v Wood |  | 2011-03100 | 2014 NY Slip Op 03549
Cases Decided May 7, 2014
Title | Judge | Docket No. | Slip Opinion No.
Anisman v Nissman |  | 2013-01297 | 2014 NY Slip Op 03218
Bakioglu v Tornabene |  | 2013-04454 | 2014 NY Slip Op 03219
Bayport Constr. Corp. v BHS Ins. Agency |  | 2012-10500 | 2014 NY Slip Op 03220
Borawski v Abulafia |  | 2012-09161 | 2014 NY Slip Op 03221
Boyle v Pottery Barn Outlet |  | 2012-03728 | 2014 NY Slip Op 03222
Castagna v Almaghrabi |  | 2013-04352 | 2014 NY Slip Op 03223
Clark v Clark |  | 2012-07601 | 2014 NY Slip Op 03224
Cole v Richard G. Karanfilian, M.D., P.C. |  | 2012-07661 | 2014 NY Slip Op 03225
Davis v Davis |  | 2012-05709 | 2014 NY Slip Op 03226
Delgado v Authentic Memorabilia, LLC |  | 2012-05709 | 2014 NY Slip Op 03227
Deutsche Bank Natl. Trust Co. v Ramirez |  | 2012-10505 | 2014 NY Slip Op 03228
Emigrant Mtge. Co., Inc. v Persad |  | 2013-05866 | 2014 NY Slip Op 03229
Fernandez v Babylon Mun. Solid Waste |  | 2013-01265 | 2014 NY Slip Op 03230
Galli v Galli |  | 2012-09802 | 2014 NY Slip Op 03231
Gordon v Ifeanyichukwu Chuba Orakwue Obiakor |  | 2012-07978 | 2014 NY Slip Op 03232
Greenberg v Blake |  | 2012-10694 | 2014 NY Slip Op 03233
Ingram v COSTCO Wholesale Corp. |  | 2012-05585 | 2014 NY Slip Op 03234
Kats-Kagan v City of New York |  | 2012-03440 | 2014 NY Slip Op 03235
Lipco Elec. Corp. v ASG Consulting Corp. |  | 2012-03565 | 2014 NY Slip Op 03236
Lipco Elec. Corp. v ASG Consulting Corp. |  | 2012-07610 | 2014 NY Slip Op 03237
Lui v Town of E. Hampton |  | 2012-07806 | 2014 NY Slip Op 03238
Marino & Weiss, P.C. v Cervera |  | 2013-02014 | 2014 NY Slip Op 03239
Michaan v Gazebo Hort., Inc. |  | 2013-05799 | 2014 NY Slip Op 03240
Milham v Port Auth. of N.Y. & N.J. |  | 2012-07386 | 2014 NY Slip Op 03241
Moore v Great Atl. & Pac. Tea Co., Inc. |  | 2012-10897 | 2014 NY Slip Op 03242
Nielsen Co. (US), LLC v Hudson Riv. Group, Inc. |  | 2012-11420 | 2014 NY Slip Op 03243
Oak Hollow Nursing Ctr. v Stumbo |  | 2012-06921 | 2014 NY Slip Op 03244
184 Joralemon, LLC v Brklyn Hts Condos, LLC |  | 2012-10377 | 2014 NY Slip Op 03245
People v Roache |  | 2010-01904 | 2014 NY Slip Op 03246
QPBC, Inc. v Total Automotive Warehouse, Inc. |  | 2012-10674 | 2014 NY Slip Op 03247
Rallo v Man-Dell Food Stores, Inc. |  | 2013-11139 | 2014 NY Slip Op 03248
Rodzianko v Parish of the Russian Orthodox Holy Virgin Protection Church, Inc. |  | 2012-09981 | 2014 NY Slip Op 03249
Ryan v Town of Riverhead |  | 2013-01891 | 2014 NY Slip Op 03250
Santana v Leith |  | 2013-08727 | 2014 NY Slip Op 03251
Serpas v Bell |  | 2013-01390 | 2014 NY Slip Op 03252
Sinclair v Chau |  | 2013-07403 | 2014 NY Slip Op 03253
Southeast Fin., LLC v Broadway Towing, Inc. |  | 2013-03025 | 2014 NY Slip Op 03254
TD Bank, N.A. v 126 Spruce St., LLC |  | 2012-10956 | 2014 NY Slip Op 03255
Torres v Saint Vincent's Catholic Med. Ctrs. of N.Y. |  | 2011-10789 | 2014 NY Slip Op 03256
Turco v Turco |  | 2011-10789 | 2014 NY Slip Op 03257
Turco v Turco |  | 2012-08721 | 2014 NY Slip Op 03258
Waggaman v Arauzo |  | 2012-11113 | 2014 NY Slip Op 03259
Zavelin v Greenberg |  | 2012-09781 | 2014 NY Slip Op 03260
Ziv v Tellkamp |  | 2013-00938 | 2014 NY Slip Op 03261
Matter of Graziani C. A. (Lisa A.) |  | 2012-08949 | 2014 NY Slip Op 03262
Matter of Andries v Cox |  | 2012-08049 | 2014 NY Slip Op 03263
Matter of Archer v Carrion |  | 2013-05522 | 2014 NY Slip Op 03264
Matter of Gaymon v MTA Bus Co. |  | 2012-01890 | 2014 NY Slip Op 03265
Matter of Hamad v Rizika |  | 2012-10786 | 2014 NY Slip Op 03266
Matter of Heuser v Chavez |  | 2012-03993 | 2014 NY Slip Op 03267
Matter of Kirkpatrick v Wambua |  | 2012-09384 | 2014 NY Slip Op 03268
Matter of Frank A. L. v Vaccarelli |  | 2011-11392 | 2014 NY Slip Op 03269
Matter of Liddell v New York State Off. of Children & Family Servs. |  | 2013-04540 | 2014 NY Slip Op 03270
Matter of Local 342, Long Is. Pub. Serv. Employees v Huntington |  | 2012-08817 | 2014 NY Slip Op 03271
Matter of Adriel R. (David P.) |  | 2013-05392 | 2014 NY Slip Op 03272
Matter of Son v Ramos |  | 2013-04368 | 2014 NY Slip Op 03273
People v Bennett |  | 2010-04604 | 2014 NY Slip Op 03274
People v Berezny |  | 2011-02792 | 2014 NY Slip Op 03275
People v Cruz |  | 2010-11451 | 2014 NY Slip Op 03276
People v Davis |  | 2012-04045 | 2014 NY Slip Op 03277
People v Lewis |  | 2011-04170ON MOTION | 2014 NY Slip Op 03278
People v Lezama |  | 2012-04994 | 2014 NY Slip Op 03279
People v Mantock |  | 2012-00294 | 2014 NY Slip Op 03280
People v McCormick |  | 2012-02337 | 2014 NY Slip Op 03281
People v Myers |  | 2012-04517 | 2014 NY Slip Op 03282
People v Ormejuste |  | 2012-07398 | 2014 NY Slip Op 03283
People v Sanders |  | 2010-10181 | 2014 NY Slip Op 03284
People v Santana |  | 2012-08781 | 2014 NY Slip Op 03285
People v Santiago |  | 2010-04291 | 2014 NY Slip Op 03286
People v Vines |  | 2012-00109 | 2014 NY Slip Op 03287
People v Webb |  | 2012-00287 | 2014 NY Slip Op 03288
People v Whitney |  | 2011-08449 | 2014 NY Slip Op 03289
People v Chen |  | 2011-11824 | 2014 NY Slip Op 03290
Home | Contents | Site Search | Publications | Decisions | Decision Search Citation Services | Archives | Style Manual | Legal Research Portal New York State Law Reporting Bureau 17 Lodge Street, Albany, NY 12207 phone: (518) 453-6900 fax: (518) 426-1640 Friday, July 4, 2014